# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcloudauth.endpoint import endpoint_data

class SubmitVerificationRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Cloudauth', '2018-09-16', 'SubmitVerification','cloudauth')
		self.set_protocol_type('https')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_Biz(self):
		return self.get_body_params().get('Biz')

	def set_Biz(self,Biz):
		self.add_body_params('Biz', Biz)

	def get_SourceIp(self):
		return self.get_query_params().get('SourceIp')

	def set_SourceIp(self,SourceIp):
		self.add_query_param('SourceIp',SourceIp)

	def get_Materials(self):
		return self.get_body_params().get('Material')

	def set_Materials(self, Materials):
		for depth1 in range(len(Materials)):
			if Materials[depth1].get('MaterialType') is not None:
				self.add_body_params('Material.' + str(depth1 + 1) + '.MaterialType', Materials[depth1].get('MaterialType'))
			if Materials[depth1].get('Value') is not None:
				self.add_body_params('Material.' + str(depth1 + 1) + '.Value', Materials[depth1].get('Value'))

	def get_TicketId(self):
		return self.get_body_params().get('TicketId')

	def set_TicketId(self,TicketId):
		self.add_body_params('TicketId', TicketId)